# Contributing Guidelines

This document contains information and guidelines about contributing to this project.
Please read it before you start participating.

## Asking Questions

You can ask questions through our Slack channel [#pi-idc-shankar-team](https://intuit-teams.slack.com/messages/G98QRJW5Q) or by adding a [github issue](/issues).

## Coding conventions

Please follow standard practice for the language you are adding.

## Testing conventions

* Write tests to cover any new code
* Try to write code that is unit-testable, and write unit tests
* If appropriate also create integration tests

## Branching conventions

* Keep branches short-lived
* Merge to master in small increments
* Delete branch after merging a PR to master

## Commit-message conventions

* Include JIRA story or GitHub issue in commit subject
* Write a description of the changes made in the commit message

## Submitting a Pull Request

You can submit a pull request to this repository at any time. Follow these guidelines to make it easier for you and the project maintainers to merge the PR to mainline:

If you are external to the team please start by forking the project. If you are on the team please coordinate with them to produce an appropriate branch.

1. [Fork](http://help.github.com/fork-a-repo/) the project, clone your fork,
   and configure the remotes:

   ```bash
   # Clone your fork of the repo into the current directory
   git clone git@github.intuit.com/cloud-logging/aws-fluent-plugin-kinesis-intuit.git
   # Navigate to the newly cloned directory
   cd oil-federated-search
   # Assign the original repo to a remote called "upstream"
   git remote add upstream https://github.intuit.com/cloud-logging/aws-fluent-plugin-kinesis-intuit.git
   ```

2. Run the unit tests.  If you added new functionality, extend existing test cases or add new ones.

3. If you cloned a while ago, get the latest changes from upstream:

   ```bash
   git checkout master
   git pull upstream master
   ```

4. Create a new topic branch (off the main project development branch) to
   contain your feature, change, or fix:

   ```bash
   git checkout -b <topic-branch-name>
   ```

5. Commit your changes in logical chunks. For any Git project, some good rules
   for commit messages are
   * the first line is commit summary, 50 characters or less,
   * followed by an empty line
   * followed by an explanation of the commit, wrapped to 72 characters.

   The first line of a commit message becomes the **title** of a pull request on
   GitHub, like the subject line of an email. Including the key info in the
   first line will help us respond faster to your pull.

   If your pull request has multiple commits which revise the same lines of
   code, it is better to [squash](http://davidwalsh.name/squash-commits-git)
   those commits together into one logical unit.

   But you don't always have to squash &mdash; it is fine for a pull request to
   contain multiple commits when there is a logical reason for the separation.

6. Push your topic branch up to your fork:

   ```bash
   git push origin <topic-branch-name>
   ```

7. [Open a Pull Request](https://help.github.com/articles/using-pull-requests/)
    with a clear title and description.

8. After your Pull Request is away, you might want to get yourself back onto
   `master` and delete the topic branch:

   ```bash
   git checkout master
   git branch -D <topic-branch-name>
   ```

Please refer to  [this wiki](https://github.intuit.com/fabric-app-shells/mobile-shell-ios/wiki/How-to-develop-across-multiple-repositories) if you want to make changes across multiple repositories.

<sub><sup>Pull request instructions from [Sergey Alexandrov](https://github.com/taketwo)</sup></sub>

## Reporting Other Issues

A great way to contribute to the project
is to send a detailed issue when you encounter an problem.
We always appreciate a well-written, thorough bug report.

Check that the project issues database
doesn't already include that problem or suggestion before submitting an issue.
If you find a match, add a quick "+1" or "I have this problem too."
Doing this helps prioritize the most common problems and requests.

When reporting issues, please include the following:

- Steps to reproduce
- Expected Results
- Actual Results
- Version if available
- Environment Setup

Please be descriptive in each and be sure that the report can easily be reproduced if possible.

This information will help us review and fix your issue faster.

## Developer's Certificate of Origin

By making a contribution to this project, I certify that:

- (a) The contribution was created in whole or in part by me and I
      have the right to submit it under the open source license
      indicated in the file; or

- (b) The contribution is based upon previous work that, to the best
      of my knowledge, is covered under an appropriate open source
      license and I have the right under that license to submit that
      work with modifications, whether created in whole or in part
      by me, under the same open source license (unless I am
      permitted to submit under a different license), as indicated
      in the file; or

- (c) The contribution was provided directly to me by some other
      person who certified (a), (b) or (c) and I have not modified
      it.

- (d) I understand and agree that this project and the contribution
      are public and that a record of the contribution (including all
      personal information I submit with it, including my sign-off) is
      maintained indefinitely and may be redistributed consistent with
      this project or the open source license(s) involved.

## Code of Conduct

The Code of Conduct governs how we behave in public or in private
whenever the project will be judged by our actions.
We expect it to be honored by everyone who contributes to this project.

---

<sub><sup>*Some of the ideas and wording for the statements above were based on work by the [AlamoFire](https://github.com/Alamofire/Alamofire/blob/master/CONTRIBUTING.md) community. We commend them for their efforts to facilitate collaboration in their projects.*</sup></sub>
